@@ -9,30 +9,28 @@
 	class general_exception
 	{
 	public:
-		general_exception(string str_para): str(str_para) {}
-		string str;
-		
+		general_exception() {}	
 	};
 
 
 	class var_nonpositive_exception : public general_exception
 	{
 	public:
-		var_nonpositive_exception(string str_para): general_exception(str_para) {}
+		var_nonpositive_exception(): general_exception() {}
 	};
 
 
 	class memory_exception : public general_exception
 	{
 	public:
-		memory_exception(string str_para): general_exception(str_para) {}
+		memory_exception(): general_exception() {}
 	};
 
 
 	class file_exception : public general_exception
 	{
 	public:
-		file_exception(string str_para): general_exception(str_para) {}
+		file_exception(): general_exception() {}
 	};
 
 #endif
